@@ -1,6 +1,23 @@
-
+#' Print a Short Summary of parameter estimates of a shared frailty model
+#' 
+#' Prints a short summary of parameter estimates of a 'frailtyPenal' object
+#' 
+#' 
+#' @usage \method{print}{frailtyPenal}(x, digits = max(options()$digits - 4, 6),
+#' ...)
+#' @param x the result of a call to the frailtyPenal function.
+#' @param digits number of digits to print.
+#' @param \dots other unused arguments.
+#' @return
+#' 
+#' Print the parameter estimates of the survival or hazard functions.
+#' @seealso \code{\link{frailtyPenal}}
+#' @keywords methods
+##' @export
 "print.frailtyPenal" <- function (x, digits = max(options()$digits - 4, 6), ...) 
 {
+
+  if (x$istop == 1){
 # plot des coefficient dependant du temps
 	if ((x$nvartimedep != 0) & (x$istop == 1)){
 		par(mfrow=c(1,x$nvartimedep))
@@ -8,6 +25,7 @@
 			matplot(x$BetaTpsMat[,1],x$BetaTpsMat[,(2:4)+4*i],col="blue",type="l",lty=c(1,2,2),xlab="t",ylab="beta(t)",main=x$Names.vardep[i+1],ylim=c(min(x$BetaTpsMat[,-1]),max(x$BetaTpsMat[,-1])))
 		}
 	}
+  }
 
 	if (!is.null(cl <- x$call)){
 		cat("Call:\n")
@@ -52,7 +70,7 @@
 			cat("  The maximum number of knots is 20","\n")
 		}
 	}else{
-		if ((x$typeof == 1) & (x$indic.nb.int1 == 1)) cat("  The maximum number of time intervals is 20","\n")
+		if ((x$typeof == 1) & (x$indic.nb.int == 1)) cat("  The maximum number of time intervals is 20","\n")
 	}
 #AD
 
@@ -68,13 +86,13 @@
 				seH <- sqrt(x$varH)
 				seHIH <- sqrt(x$varHIH)
 			}
-			if (x$typeof == 0){
-				tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
-				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)
-			}else{
-				tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
-				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)
-			}
+		  if (x$typeof == 0){
+		    tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, ifelse(signif(1 - pchisq((coef/seH)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((coef/seH)^2, 1), digits - 1))) # ifelse pour eviter que R n'affiche pval = 0 lorsque celle-ci est tres petite
+		    if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,ifelse(x$p.global_chisq == 0, "< 1e-16", x$p.global_chisq))
+		  }else{
+		    tmp <- cbind(coef, exp(coef), seH, coef/seH, ifelse(signif(1 - pchisq((coef/seH)^2, 1), digits - 1) == 0, "< 1e-16", signif(1 - pchisq((coef/seH)^2, 1), digits - 1)))
+		    if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,ifelse(x$p.global_chisq == 0, "< 1e-16", x$p.global_chisq))
+		  }
 		
 			cat("\n")
 			if (!is.null(frail)){
@@ -89,7 +107,7 @@
 					cat("  using a Parametrical approach for the hazard function","\n")
 				}
 				if (x$nvartimedep != 0) cat("  and some time-dependant covariates","\n")
-				if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
+				if (x$n.strat>1) cat("  (Stratification structure used) :",x$n.strat,"strata \n")
 			}else{
 				if (x$typeof == 0){
 					cat("  Cox proportional hazards model parameter estimates ","\n")
@@ -99,7 +117,7 @@
 					cat("  using a Parametrical approach for the hazard function","\n")
 				}
 				if (x$nvartimedep != 0) cat("  and some time-dependant covariates","\n")
-				if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
+				if (x$n.strat>1) cat("  (Stratification structure used) :",x$n.strat,"strata \n")
 			}
 			
 			if (x$typeof == 0){
@@ -170,13 +188,13 @@
 # 			}
 
 			if (x$logNormal == 0){
-				cat("    Frailty parameter, Theta:", frail, "(SE (H):",
-				seH, ")", "p =", signif(1 - pnorm(frail/seH), digits - 1), "\n")
+			  cat("    Frailty parameter, Theta:", frail, "(SE (H):",
+			  seH, ")", "p =", ifelse(signif(1 - pnorm(frail/seH), digits - 1) == 0, "< 1e-16", signif(1 - pnorm(frail/seH), digits - 1)), "\n")
 			}else{
-				cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
-				seH, ")", "p =", signif(1 - pnorm(frail/seH), digits - 1), "\n")
+			  cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
+			  seH, ")", "p =", ifelse(signif(1 - pnorm(frail/seH), digits - 1) == 0, "< 1e-16", signif(1 - pnorm(frail/seH), digits - 1)), "\n")
 			}
-
+			
         }
 
 		cat(" \n")
@@ -231,7 +249,7 @@
 		
 		cat( "\n")
 		cat("      number of iterations: ", x$n.iter,"\n")
-		if ((x$typeof == 1) & (x$indic.nb.int1 == 1)){
+		if ((x$typeof == 1) & (x$indic.nb.int == 1)){
 			cat("      Exact number of time intervals used: 20","\n")
 		 }else{
 		 	if (x$typeof == 1) cat("      Exact number of time intervals used: ",x$nbintervR,"\n")
@@ -241,17 +259,16 @@
 			cat("      Exact number of knots used: ", x$n.knots, "\n")
 	
 			if (!x$cross.Val){
-				cat("      Value of the smoothing parameter: ", x$kappa[1])
-				if (x$n.strat==2) cat(" ", x$kappa[2])
+				cat("      Value of the smoothing parameter: ", x$kappa, sep=" ")
 			}
 		
 			if (x$cross.Val){
 				if (is.null(frail)){
-					cat("      Smoothing parameter estimated by Cross validation: ", x$kappa[1])
+					cat("      Smoothing parameter estimated by Cross validation: ", x$kappa, sep=" ")
 				}else{ 
 					cat("      Best smoothing parameter estimated by")
 					cat("\n")
-					cat("      an approximated Cross validation: ", x$kappa[1])
+					cat("      an approximated Cross validation: ", x$kappa, sep=" ")
 				}
 			}
 			cat(", DoF: ", formatC(-x$DoF, format="f",digits=2))
